/*============================================================================
*
*  LOGIC CORE:          OV2640初始化寄存器表(RGB模式专用)
*  MODULE NAME:         ov2640_init_table_rgb()
*  COMPANY:             武汉芯路恒科技有限公司
*                       http://xiaomeige.taobao.com
*  author:				小梅哥
*  Website:				www.corecourse.cn
*  REVISION HISTORY:  
*
*  Revision: 			1.0  04/10/2019
*  Description: 		Initial Release.
*
*  FUNCTIONAL DESCRIPTION:
===========================================================================*/

module ov2640_init_table_rgb(
	addr,
	clk, 
	q
);	
	input clk;
	input [(ADDR_WIDTH-1):0] addr;
	output reg [(DATA_WIDTH-1):0] q;
	
	parameter DATA_WIDTH=16;
	parameter ADDR_WIDTH=8;

	// Declare the ROM variable
	reg [DATA_WIDTH-1:0] rom[2**ADDR_WIDTH-1:0];

	initial begin
		rom[0  ] = 16'hff_00;//选中DSP Address
		rom[1  ] = 16'h2c_ff;
		rom[2  ] = 16'h2e_df;
		rom[3  ] = 16'hff_01;
		rom[4  ] = 16'h3c_32;
		//
		rom[5  ] = 16'h11_00;
		rom[6  ] = 16'h09_02;
		rom[7  ] = 16'h04_D8;//水平镜像,垂直翻转
		rom[8  ] = 16'h13_e5;
		rom[9  ] = 16'h14_48;
		rom[10 ] = 16'h2c_0c;
		rom[11 ] = 16'h33_78;
		rom[12 ] = 16'h3a_33;
		rom[13 ] = 16'h3b_fB;
		//
		rom[14 ] = 16'h3e_00;
		rom[15 ] = 16'h43_11;
		rom[16 ] = 16'h16_10;
		//
		rom[17 ] = 16'h39_92;
		//
		rom[18 ] = 16'h35_da;
		rom[19 ] = 16'h22_1a;
		rom[20 ] = 16'h37_c3;
		rom[21 ] = 16'h23_00;
		rom[22 ] = 16'h34_c0;
		rom[23 ] = 16'h36_1a;
		rom[24 ] = 16'h06_88;
		rom[25 ] = 16'h07_c0;
		rom[26 ] = 16'h0d_87;
		rom[27 ] = 16'h0e_41;
		rom[28 ] = 16'h4c_00;
		rom[29 ] = 16'h48_00;
		rom[30 ] = 16'h5B_00;
		rom[31 ] = 16'h42_03;
		//
		rom[32 ] = 16'h4a_81;
		rom[33 ] = 16'h21_99;
		//
		rom[34 ] = 16'h24_40;
		rom[35 ] = 16'h25_38;
		rom[36 ] = 16'h26_82;
		rom[37 ] = 16'h5c_00;
		rom[38 ] = 16'h63_00;
		rom[39 ] = 16'h46_22;
		rom[40 ] = 16'h0c_3c;
		//
		rom[41 ] = 16'h61_70;
		rom[42 ] = 16'h62_80;
		rom[43 ] = 16'h7c_05;
		//
		rom[44 ] = 16'h20_80;
		rom[45 ] = 16'h28_30;
		rom[46 ] = 16'h6c_00;
		rom[47 ] = 16'h6d_80;
		rom[48 ] = 16'h6e_00;
		rom[49 ] = 16'h70_02;
		rom[50 ] = 16'h71_94;
		rom[51 ] = 16'h73_c1;
		rom[52 ] = 16'h3d_34;
		rom[53 ] = 16'h5a_57;
		//根据分辨率不同而设置
		rom[54 ] = 16'h12_40;//SVGA 800*600
		rom[55 ] = 16'h17_11;//传感器窗口设置
		rom[56 ] = 16'h18_43;//传感器窗口设置
		rom[57 ] = 16'h19_00;//传感器窗口设置
		rom[58 ] = 16'h1a_4b;//传感器窗口设置
		rom[59 ] = 16'h32_09;
		rom[60 ] = 16'h37_c0;
		//
		rom[61 ] = 16'h4f_ca;
		rom[62 ] = 16'h50_a8;
		rom[63 ] = 16'h5a_23;
		rom[64 ] = 16'h6d_00;
		rom[65 ] = 16'h3d_38;
		//
		rom[66 ] = 16'hff_00;
		rom[67 ] = 16'he5_7f;
		rom[68 ] = 16'hf9_c0;
		rom[69 ] = 16'h41_24;
		rom[70 ] = 16'he0_14;
		rom[71 ] = 16'h76_ff;
		rom[72 ] = 16'h33_a0;
		rom[73 ] = 16'h42_20;
		rom[74 ] = 16'h43_18;
		rom[75 ] = 16'h4c_00;
		rom[76 ] = 16'h87_d5;
		rom[77 ] = 16'h88_3f;
		rom[78 ] = 16'hd7_03;
		rom[79 ] = 16'hd9_10;
		rom[80 ] = 16'hd3_82;
		//
		rom[81 ] = 16'hc8_08;
		rom[82 ] = 16'hc9_80;
		//
		rom[83 ] = 16'h7c_00;
		rom[84 ] = 16'h7d_00;
		rom[85 ] = 16'h7c_03;
		rom[86 ] = 16'h7d_48;
		rom[87 ] = 16'h7d_48;
		rom[88 ] = 16'h7c_08;
		rom[89 ] = 16'h7d_20;
		rom[90 ] = 16'h7d_10;
		rom[91 ] = 16'h7d_0e;
		//
		rom[92 ] = 16'h90_00;
		rom[93 ] = 16'h91_0e;
		rom[94 ] = 16'h91_1a;
		rom[95 ] = 16'h91_31;
		rom[96 ] = 16'h91_5a;
		rom[97 ] = 16'h91_69;
		rom[98 ] = 16'h91_75;
		rom[99 ] = 16'h91_7e;
		rom[100] = 16'h91_88;
		rom[101] = 16'h91_8f;
		rom[102] = 16'h91_96;
		rom[103] = 16'h91_a3;
		rom[104] = 16'h91_af;
		rom[105] = 16'h91_c4;
		rom[106] = 16'h91_d7;
		rom[107] = 16'h91_e8;
		rom[108] = 16'h91_20;
		//
		rom[109] = 16'h92_00;
		rom[110] = 16'h93_06;
		rom[111] = 16'h93_e3;
		rom[112] = 16'h93_05;
		rom[113] = 16'h93_05;
		rom[114] = 16'h93_00;
		rom[115] = 16'h93_04;
		rom[116] = 16'h93_00;
		rom[117] = 16'h93_00;
		rom[118] = 16'h93_00;
		rom[119] = 16'h93_00;
		rom[120] = 16'h93_00;
		rom[121] = 16'h93_00;
		rom[122] = 16'h93_00;
		//
		rom[123] = 16'h96_00;
		rom[124] = 16'h97_08;
		rom[125] = 16'h97_19;
		rom[126] = 16'h97_02;
		rom[127] = 16'h97_0c;
		rom[128] = 16'h97_24;
		rom[129] = 16'h97_30;
		rom[130] = 16'h97_28;
		rom[131] = 16'h97_26;
		rom[132] = 16'h97_02;
		rom[133] = 16'h97_98;
		rom[134] = 16'h97_80;
		rom[135] = 16'h97_00;
		rom[136] = 16'h97_00;
		//
		rom[137] = 16'hc3_ed;
		rom[138] = 16'ha4_00;
		rom[139] = 16'ha8_00;
		rom[140] = 16'hc5_11;
		rom[141] = 16'hc6_51;
		rom[142] = 16'hbf_80;
		rom[143] = 16'hc7_10;
		rom[144] = 16'hb6_66;
		rom[145] = 16'hb8_A5;
		rom[146] = 16'hb7_64;
		rom[147] = 16'hb9_7C;
		rom[148] = 16'hb3_af;
		rom[149] = 16'hb4_97;
		rom[150] = 16'hb5_FF;
		rom[151] = 16'hb0_C5;
		rom[152] = 16'hb1_94;
		rom[153] = 16'hb2_0f;
		rom[154] = 16'hc4_5c;
		//根据分辨率不同而设置
		rom[155] = 16'hc0_64;//图像尺寸设置 //800 = 100(0x64) * 8
		//rom[156] = 16'hc1_4B;//图像尺寸设置 //600 = 75(0x4B) * 8 //3C
		rom[156] = 16'hc1_3C;//图像尺寸设置 //600 = 75(0x4B) * 8 //3C
		rom[157] = 16'h8c_00;//图像尺寸设置
		rom[158] = 16'h86_3D;
		rom[159] = 16'h50_00;
		rom[160] = 16'h51_C8;//图像窗口设置
		rom[161] = 16'h52_96;//图像窗口设置
		rom[162] = 16'h53_00;//图像窗口设置
		rom[163] = 16'h54_00;//图像窗口设置
		rom[164] = 16'h55_00;//图像窗口设置
		rom[165] = 16'h5a_C8;
		rom[166] = 16'h5b_96;
		rom[167] = 16'h5c_00;
		
		//rom[168] = 16'hd3_02;//auto设置要小心   82
		rom[168] = 16'hd3_82;//auto设置要小心   82
		//
		rom[169] = 16'hc3_ed;
		rom[170] = 16'h7f_00;
		//rom[171] = 16'hda_09;//08
		rom[171] = 16'hda_08;//08
		rom[172] = 16'he5_1f;
		rom[173] = 16'he1_67;
		rom[174] = 16'he0_00;
		rom[175] = 16'hdd_7f;
		rom[176] = 16'h05_00;
	end

	always @ (posedge clk)
	begin
		q <= rom[addr];
	end

endmodule
