module ov2640_sdram_tft(
	input 			clk,
	input 			rst_n,
	
	//sdram control
	output			sdram_clk,
	output			sdram_cke,
	output			sdram_cs_n,
	output			sdram_we_n,
	output			sdram_cas_n,
	output			sdram_ras_n,
	output  [1:0]	sdram_dqm,
	output  [1:0]	sdram_ba,
	output  [12:0]	sdram_addr,
	inout   [15:0]	sdram_dq,
	
	//cmos interface
	output			cmos_sclk,
	inout				cmos_sdat,
	input				cmos_vsync,
	input				cmos_href,
	input				cmos_pclk,
	output			cmos_xclk,
	input 	[7:0]	cmos_data,
	output			cmos_rst_n,
	output			cmos_pwdn,
	
	//tft output
	output  [15:0] tft_rgb,  //TFT数据输出
	output         tft_hs,   //TFT行同步信号
	output         tft_vs,   //TFT场同步信号
	output         tft_clk,  //TFT像素时钟
	output         tft_de,   //TFT数据使能
	output         tft_pwm  //TFT背光控制
);
	parameter IMG_WIDTH  = 800;
	parameter IMG_HIGHT  = 480;
	
	wire clk_sdr_ctrl;
	wire clk_50m;
	wire clk_24m;
	wire clk_vga;//33m
	assign cmos_xclk = clk_24m;
	pll pll_inst (
		.inclk0(clk),
		.c0(clk_sdr_ctrl),
		.c1(sdram_clk),
		.c2(clk_50m),
		.c3(clk_24m),
		.c4(clk_vga)
	);

	//-----------------------------------------------
	//摄像头初始化配置
	wire Init_Done;
	cmos_init cmos_init(
		.Clk(clk_50m),
		.Rst_n(rst_n),
		.Init_Done(Init_Done),
		.cmos_rst_n(cmos_rst_n),
		.cmos_pwdn(cmos_pwdn),
		.i2c_sclk(cmos_sclk),
		.i2c_sdat(cmos_sdat)
	);
	
	//-----------------------------------------------
	//摄像头1,摄像头2图像输出
	wire fifo_aclr;
	wire fifo_wrreq;
	wire [15:0] fifo_wrdata;
	cmos_8_16 cmos_capture1(
		.pclk(cmos_pclk),
		.rst_n(rst_n),
		.data_i(cmos_data),
		.Init_Done(Init_Done),
		.cmos_vsync(cmos_vsync),
		.href(cmos_href),
		.fifo_aclr(fifo_aclr),
		.data_o(fifo_wrdata),
		.de(fifo_wrreq)
	);
	
	wire [15:0] RGB_DATA;
	wire DataReq;
	wire frame_begin;
	Sdram_Control_4Port Sdram_Control_4Port(
		//	HOST Side
		.CTRL_CLK(clk_sdr_ctrl),	//输入参考时钟，默认100M，如果为其他频率，请修改sdram_pll核设置
		.RESET_N(rst_n),	//复位输入，低电平复位

		//	FIFO Write Side 1
		.WR1_DATA(fifo_wrdata),			//写入端口1的数据输入端，16bit
		.WR1(fifo_wrreq),					//写入端口1的写使能端，高电平写入
		.WR1_ADDR(0),			//写入端口1的写起始地址
		.WR1_MAX_ADDR(IMG_WIDTH * IMG_HIGHT),		//写入端口1的写入最大地址
		.WR1_LENGTH(256),			//一次性写入数据长度
		.WR1_LOAD(fifo_aclr),			//写入端口1清零请求，高电平清零写入地址和fifo
		.WR1_CLK(cmos_pclk),				//写入端口1 fifo写入时钟
		.WR1_FULL(),			//写入端口1 fifo写满信号
		.WR1_USE(),				//写入端口1 fifo已经写入的数据长度

		//	FIFO Write Side 2
		.WR2_DATA(16'd0),			//写入端口2的数据输入端，16bit
		.WR2(1'b0),					//写入端口2的写使能端，高电平写入
		.WR2_ADDR(0),			//写入端口2的写起始地址
		.WR2_MAX_ADDR(0),		//写入端口2的写入最大地址
		.WR2_LENGTH(8),			//一次性写入数据长度
		.WR2_LOAD(1'b0),			//写入端口2清零请求，高电平清零写入地址和fifo
		.WR2_CLK(1'b0),				//写入端口2 fifo写入时钟
		.WR2_FULL(),			//写入端口2 fifo写满信号
		.WR2_USE(),				//写入端口2 fifo已经写入的数据长度

		//	FIFO Read Side 1
		.RD1_DATA(RGB_DATA),			//读出端口1的数据输出端，16bit
		.RD1(DataReq),					//读出端口1的读使能端，高电平读出
		.RD1_ADDR(0),			//读出端口1的读起始地址
		.RD1_MAX_ADDR(IMG_WIDTH * IMG_HIGHT),		//读出端口1的读出最大地址
		.RD1_LENGTH(256),			//一次性读出数据长度
		.RD1_LOAD(!rst_n | frame_begin),			//读出端口1 清零请求，高电平清零读出地址和fifo
		.RD1_CLK(clk_vga),			//读出端口1 fifo读取时钟
		.RD1_EMPTY(),			//读出端口1 fifo读空信号
		.RD1_USE(),				//读出端口1 fifo已经还可以读取的数据长度

		//	FIFO Read Side 2
		.RD2_DATA(),			//读出端口2的数据输出端，16bit
		.RD2(1'b0),					//读出端口2的读使能端，高电平读出
		.RD2_ADDR(),			//读出端口2的读起始地址
		.RD2_MAX_ADDR(),		//读出端口2的读出最大地址
		.RD2_LENGTH(),			//一次性读出数据长度
		.RD2_LOAD(),			//读出端口2清零请求，高电平清零读出地址和fifo
		.RD2_CLK(1'b0),				//读出端口2 fifo读取时钟
		.RD2_EMPTY(),			//读出端口2 fifo读空信号
		.RD2_USE(),				//读出端口2 fifo已经还可以读取的数据长度

		//	SDRAM Side
		.SA(sdram_addr),		//SDRAM 地址线，
		.BA(sdram_ba),		//SDRAM bank地址线
		.CS_N(sdram_cs_n),		//SDRAM 片选信号
		.CKE(sdram_cke),		//SDRAM 时钟使能
		.RAS_N(sdram_ras_n),	//SDRAM 行选中信号
		.CAS_N(sdram_cas_n),	//SDRAM 列选中信号
		.WE_N(sdram_we_n),		//SDRAM 写请求信号
		.DQ(sdram_dq),		//SDRAM 双向数据总线
		.DQM(sdram_dqm)		//SDRAM 数据总线高低字节屏蔽信号
	);

	assign tft_pwm = rst_n;
	disp_driver disp_driver(
		.ClkDisp(clk_vga),
		.Rst_n(rst_n),
		.Data(RGB_DATA),
		.DataReq(DataReq),
		.H_Addr(),
		.V_Addr(),
		.Disp_HS(tft_hs),
		.Disp_VS(tft_vs),
		.Disp_Red(tft_rgb[15:11]),
		.Disp_Green(tft_rgb[10:5]),
		.Disp_Blue(tft_rgb[4:0]),
		.frame_begin(frame_begin),
		.Disp_DE(tft_de),
		.Disp_PCLK(tft_clk)
	);

endmodule
